# mmon [![PyPI version](https://badge.fury.io/py/mmon.svg)](https://badge.fury.io/py/mmon) [![Release Building](https://github.com/iaalm/mmon/actions/workflows/release.yml/badge.svg)](https://github.com/iaalm/mmon/actions/workflows/release.yml)
A customizable (BingChat-like) chat bot.

![A chatbot image generated by algorithm](./logo.jpg)

## Install
```bash
pip install -U mmon
```

Set environment variable in your `~/.bashrc`, `~/.zshrc`, etc.
```bash
export OPENAI_API_KEY=sk~XXXXXXXX
```
Or, to use Azure OpenAI endpoint, set following environment variable:
```bash
export OPENAI_API_KEY=XXXXXXXXXX
export OPENAI_API_BASE=https://XXXXXX.openai.azure.com/
export OPENAI_API_TYPE=azure
export OPENAI_API_VERSION=2023-07-01-preview
# Use a deploymetn of gpt-3.5-turbo or gpt-4 with version 0613 or later
export MMON_DEPLOYMENT=gpt-35-turbo-16k
```
When you first run `mmon`, it will generate config file in `~/.mmon_cfg.json` based on the environment variable (and ignore environment variable afterward).

## Usage
```bash
python -m mmon
# or
mmon
```
